@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015 - 2018, Nordic Semiconductor ASA
+ * Copyright (c) 2015 - 2020, Nordic Semiconductor ASA
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -46,24 +46,21 @@ extern "C" {
  * @brief   Pulse Width Modulation (PWM) peripheral driver.
  */
 
-/**
- * @brief PWM driver instance data structure.
- */
+/** @brief PWM driver instance data structure. */
 typedef struct
 {
     NRF_PWM_Type * p_registers;  ///< Pointer to the structure with PWM peripheral instance registers.
-    uint8_t        drv_inst_idx; ///< Driver instance index.
+    uint8_t        drv_inst_idx; ///< Index of the driver instance. For internal use only.
 } nrfx_pwm_t;
 
-/**
- * @brief Macro for creating a PWM driver instance.
- */
+/** @brief Macro for creating a PWM driver instance. */
 #define NRFX_PWM_INSTANCE(id)                               \
 {                                                           \
     .p_registers  = NRFX_CONCAT_2(NRF_PWM, id),             \
     .drv_inst_idx = NRFX_CONCAT_3(NRFX_PWM, id, _INST_IDX), \
 }
 
+#ifndef __NRFX_DOXYGEN__
 enum {
 #if NRFX_CHECK(NRFX_PWM0_ENABLED)
     NRFX_PWM0_INST_IDX,
@@ -79,6 +76,7 @@ enum {
 #endif
     NRFX_PWM_ENABLED_COUNT
 };
+#endif
 
 /**
  * @brief This value can be provided instead of a pin number for any channel
@@ -87,15 +85,10 @@ enum {
  */
 #define NRFX_PWM_PIN_NOT_USED    0xFF
 
-/**
- * @brief This value can be added to a pin number to inverse its polarity
- *        (set idle state = 1).
- */
+/** @brief This value can be added to a pin number to invert its polarity (set idle state = 1). */
 #define NRFX_PWM_PIN_INVERTED    0x80
 
-/**
- * @brief PWM driver configuration structure.
- */
+/** @brief PWM driver configuration structure. */
 typedef struct
 {
     uint8_t output_pins[NRF_PWM_CHANNEL_COUNT]; ///< Pin numbers for individual output channels (optional).
@@ -107,33 +100,48 @@ typedef struct
     uint16_t           top_value;    ///< Value up to which the pulse generator counter counts.
     nrf_pwm_dec_load_t load_mode;    ///< Mode of loading sequence data from RAM.
     nrf_pwm_dec_step_t step_mode;    ///< Mode of advancing the active sequence.
+    bool               skip_gpio_cfg; ///< Skip the GPIO configuration
+                                      /**< When this flag is set, the user is responsible for
+                                       *   providing the proper configuration of the output pins,
+                                       *   as the driver does not touch it at all. */
 } nrfx_pwm_config_t;
 
 /**
  * @brief PWM driver default configuration.
+ *
+ * This configuration sets up PWM with the following options:
+ * - clock frequency: 1 MHz
+ * - count up
+ * - top value: 1000 clock ticks
+ * - load mode: common
+ * - step mode: auto
+ *
+ * @param[in] _out_0 PWM output 0 pin.
+ * @param[in] _out_1 PWM output 1 pin.
+ * @param[in] _out_2 PWM output 2 pin.
+ * @param[in] _out_3 PWM output 3 pin.
  */
-#define NRFX_PWM_DEFAULT_CONFIG                                            \
-{                                                                          \
-    .output_pins  = { NRFX_PWM_DEFAULT_CONFIG_OUT0_PIN,                    \
-                      NRFX_PWM_DEFAULT_CONFIG_OUT1_PIN,                    \
-                      NRFX_PWM_DEFAULT_CONFIG_OUT2_PIN,                    \
-                      NRFX_PWM_DEFAULT_CONFIG_OUT3_PIN },                  \
-    .irq_priority = NRFX_PWM_DEFAULT_CONFIG_IRQ_PRIORITY,                  \
-    .base_clock   = (nrf_pwm_clk_t)NRFX_PWM_DEFAULT_CONFIG_BASE_CLOCK,     \
-    .count_mode   = (nrf_pwm_mode_t)NRFX_PWM_DEFAULT_CONFIG_COUNT_MODE,    \
-    .top_value    = NRFX_PWM_DEFAULT_CONFIG_TOP_VALUE,                     \
-    .load_mode    = (nrf_pwm_dec_load_t)NRFX_PWM_DEFAULT_CONFIG_LOAD_MODE, \
-    .step_mode    = (nrf_pwm_dec_step_t)NRFX_PWM_DEFAULT_CONFIG_STEP_MODE, \
+#define NRFX_PWM_DEFAULT_CONFIG(_out_0, _out_1, _out_2, _out_3) \
+{                                                               \
+    .output_pins   = { _out_0,                                  \
+                       _out_1,                                  \
+                       _out_2,                                  \
+                       _out_3                                   \
+                     },                                         \
+    .irq_priority  = NRFX_PWM_DEFAULT_CONFIG_IRQ_PRIORITY,      \
+    .base_clock    = NRF_PWM_CLK_1MHz,                          \
+    .count_mode    = NRF_PWM_MODE_UP,                           \
+    .top_value     = 1000,                                      \
+    .load_mode     = NRF_PWM_LOAD_COMMON,                       \
+    .step_mode     = NRF_PWM_STEP_AUTO,                         \
+    .skip_gpio_cfg = false                                      \
 }
 
-
-/**
- * @brief PWM flags providing additional playback options.
- */
+/** @brief PWM flags providing additional playback options. */
 typedef enum
 {
     NRFX_PWM_FLAG_STOP = 0x01, /**< When the requested playback is finished,
-                                    the peripheral should be stopped.
+                                    the peripheral will be stopped.
                                     @note The STOP task is triggered when
                                     the last value of the final sequence is
                                     loaded from RAM, and the peripheral stops
@@ -143,7 +151,7 @@ typedef enum
                                     less than the requested number of repeats
                                     of the last value. */
     NRFX_PWM_FLAG_LOOP = 0x02, /**< When the requested playback is finished,
-                                    it should be started from the beginning.
+                                    it will be started from the beginning.
                                     This flag is ignored if used together
                                     with @ref NRFX_PWM_FLAG_STOP.
                                     @note The playback restart is done via a
@@ -157,28 +165,25 @@ typedef enum
                                     the playback restart will occur right
                                     after switching to the final value (this
                                     final value will be played only once). */
-    NRFX_PWM_FLAG_SIGNAL_END_SEQ0 = 0x04, /**< The event handler should be
+    NRFX_PWM_FLAG_SIGNAL_END_SEQ0 = 0x04, /**< The event handler is to be
                                                called when the last value
                                                from sequence 0 is loaded. */
-    NRFX_PWM_FLAG_SIGNAL_END_SEQ1 = 0x08, /**< The event handler should be
+    NRFX_PWM_FLAG_SIGNAL_END_SEQ1 = 0x08, /**< The event handler is to be
                                                called when the last value
                                                from sequence 1 is loaded. */
     NRFX_PWM_FLAG_NO_EVT_FINISHED = 0x10, /**< The playback finished event
-                                               (enabled by default) should be
+                                               (enabled by default) is to be
                                                suppressed. */
-    NRFX_PWM_FLAG_START_VIA_TASK = 0x80, /**< The playback should not be
+    NRFX_PWM_FLAG_START_VIA_TASK = 0x80, /**< The playback must not be
                                               started directly by the called
                                               function. Instead, the function
-                                              should only prepare it and
+                                              must only prepare it and
                                               return the address of the task
                                               to be triggered to start the
                                               playback. */
 } nrfx_pwm_flag_t;
 
-
-/**
- * @brief PWM driver event type.
- */
+/** @brief PWM driver event type. */
 typedef enum
 {
     NRFX_PWM_EVT_FINISHED, ///< Sequence playback finished.
@@ -189,28 +194,26 @@ typedef enum
     NRFX_PWM_EVT_STOPPED,  ///< The PWM peripheral has been stopped.
 } nrfx_pwm_evt_type_t;
 
-/**
- * @brief PWM driver event handler type.
- */
-typedef void (* nrfx_pwm_handler_t)(nrfx_pwm_evt_type_t event_type);
-
+/** @brief PWM driver event handler type. */
+typedef void (* nrfx_pwm_handler_t)(nrfx_pwm_evt_type_t event_type, void * p_context);
 
 /**
  * @brief Function for initializing the PWM driver.
  *
  * @param[in] p_instance Pointer to the driver instance structure.
- * @param[in] p_config   Pointer to the structure with initial configuration.
- *
+ * @param[in] p_config   Pointer to the structure with the initial configuration.
  * @param[in] handler    Event handler provided by the user. If NULL is passed
  *                       instead, event notifications are not done and PWM
  *                       interrupts are disabled.
+ * @param[in] p_context  Context passed to the event handler.
  *
- * @retval NRFX_SUCCESS             If initialization was successful.
- * @retval NRFX_ERROR_INVALID_STATE If the driver was already initialized.
+ * @retval NRFX_SUCCESS             Initialization was successful.
+ * @retval NRFX_ERROR_INVALID_STATE The driver was already initialized.
  */
-nrfx_err_t nrfx_pwm_init(nrfx_pwm_t const * const  p_instance,
+nrfx_err_t nrfx_pwm_init(nrfx_pwm_t const *        p_instance,
                          nrfx_pwm_config_t const * p_config,
-                         nrfx_pwm_handler_t        handler);
+                         nrfx_pwm_handler_t        handler,
+                         void *                    p_context);
 
 /**
  * @brief Function for uninitializing the PWM driver.
@@ -219,7 +222,7 @@ nrfx_err_t nrfx_pwm_init(nrfx_pwm_t const * const  p_instance,
  *
  * @param[in] p_instance Pointer to the driver instance structure.
  */
-void nrfx_pwm_uninit(nrfx_pwm_t const * const p_instance);
+void nrfx_pwm_uninit(nrfx_pwm_t const * p_instance);
 
 /**
  * @brief Function for starting a single sequence playback.
@@ -227,20 +230,20 @@ void nrfx_pwm_uninit(nrfx_pwm_t const * const p_instance);
  * To take advantage of the looping mechanism in the PWM peripheral, both
  * sequences must be used (single sequence can be played back only once by
  * the peripheral). Therefore, the provided sequence is internally set and
- * played back as both sequence 0 and sequence 1. Consequently, if end of
- * sequence notifications are required, events for both sequences should be
- * used (that means that both the @ref NRFX_PWM_FLAG_SIGNAL_END_SEQ0 flag
- * and the @ref NRFX_PWM_FLAG_SIGNAL_END_SEQ1 flag should be specified and
+ * played back as both sequence 0 and sequence 1. Consequently, if the end of
+ * sequence notifications are required, events for both sequences must be
+ * used (that is, both the @ref NRFX_PWM_FLAG_SIGNAL_END_SEQ0 flag
+ * and the @ref NRFX_PWM_FLAG_SIGNAL_END_SEQ1 flag must be specified, and
  * the @ref NRFX_PWM_EVT_END_SEQ0 event and the @ref NRFX_PWM_EVT_END_SEQ1
- * event should be handled in the same way).
+ * event must be handled in the same way).
  *
  * Use the @ref NRFX_PWM_FLAG_START_VIA_TASK flag if you want the playback
  * to be only prepared by this function, and you want to start it later by
- * triggering a task (using PPI for instance). The function will then return
+ * triggering a task (for example, by using PPI). The function will then return
  * the address of the task to be triggered.
  *
  * @note The array containing the duty cycle values for the specified sequence
- *       must be in RAM and cannot be allocated on stack.
+ *       must be in RAM and cannot be allocated on the stack.
  *       For detailed information, see @ref nrf_pwm_sequence_t.
  *
  * @param[in] p_instance     Pointer to the driver instance structure.
@@ -253,7 +256,7 @@ void nrfx_pwm_uninit(nrfx_pwm_t const * const p_instance);
  * @return Address of the task to be triggered to start the playback if the @ref
  *         NRFX_PWM_FLAG_START_VIA_TASK flag was used, 0 otherwise.
  */
-uint32_t nrfx_pwm_simple_playback(nrfx_pwm_t const * const   p_instance,
+uint32_t nrfx_pwm_simple_playback(nrfx_pwm_t const *         p_instance,
                                   nrf_pwm_sequence_t const * p_sequence,
                                   uint16_t                   playback_count,
                                   uint32_t                   flags);
@@ -267,7 +270,7 @@ uint32_t nrfx_pwm_simple_playback(nrfx_pwm_t const * const   p_instance,
  * the address of the task to be triggered.
  *
  * @note The array containing the duty cycle values for the specified sequence
- *       must be in RAM and cannot be allocated on stack.
+ *       must be in RAM and cannot be allocated on the stack.
  *       For detailed information, see @ref nrf_pwm_sequence_t.
  *
  * @param[in] p_instance     Pointer to the driver instance structure.
@@ -281,7 +284,7 @@ uint32_t nrfx_pwm_simple_playback(nrfx_pwm_t const * const   p_instance,
  * @return Address of the task to be triggered to start the playback if the @ref
  *         NRFX_PWM_FLAG_START_VIA_TASK flag was used, 0 otherwise.
  */
-uint32_t nrfx_pwm_complex_playback(nrfx_pwm_t const * const   p_instance,
+uint32_t nrfx_pwm_complex_playback(nrfx_pwm_t const *         p_instance,
                                    nrf_pwm_sequence_t const * p_sequence_0,
                                    nrf_pwm_sequence_t const * p_sequence_1,
                                    uint16_t                   playback_count,
@@ -294,7 +297,7 @@ uint32_t nrfx_pwm_complex_playback(nrfx_pwm_t const * const   p_instance,
  *
  * @param[in] p_instance Pointer to the driver instance structure.
  */
-__STATIC_INLINE void nrfx_pwm_step(nrfx_pwm_t const * const p_instance);
+NRFX_STATIC_INLINE void nrfx_pwm_step(nrfx_pwm_t const * p_instance);
 
 /**
  * @brief Function for stopping the sequence playback.
@@ -305,7 +308,7 @@ __STATIC_INLINE void nrfx_pwm_step(nrfx_pwm_t const * const p_instance);
  * might appear on the output less times than requested.
  *
  * @note This function can be instructed to wait until the playback is stopped
- *       (by setting @p wait_until_stopped to true). Note that, depending on
+ *       (by setting @p wait_until_stopped to true). Depending on
  *       the length of the PMW period, this might take a significant amount of
  *       time. Alternatively, the @ref nrfx_pwm_is_stopped function can be
  *       used to poll the status, or the @ref NRFX_PWM_EVT_STOPPED event can
@@ -316,21 +319,20 @@ __STATIC_INLINE void nrfx_pwm_step(nrfx_pwm_t const * const p_instance);
  * @param[in] wait_until_stopped If true, the function will not return until
  *                               the playback is stopped.
  *
- * @retval true  If the PWM peripheral is stopped.
- * @retval false If the PWM peripheral is not stopped.
+ * @retval true  The PWM peripheral is stopped.
+ * @retval false The PWM peripheral is not stopped.
  */
-bool nrfx_pwm_stop(nrfx_pwm_t const * const p_instance,
-                   bool wait_until_stopped);
+bool nrfx_pwm_stop(nrfx_pwm_t const * p_instance, bool wait_until_stopped);
 
 /**
  * @brief Function for checking the status of the PWM peripheral.
  *
  * @param[in] p_instance Pointer to the driver instance structure.
  *
- * @retval true  If the PWM peripheral is stopped.
- * @retval false If the PWM peripheral is not stopped.
+ * @retval true  The PWM peripheral is stopped.
+ * @retval false The PWM peripheral is not stopped.
  */
-bool nrfx_pwm_is_stopped(nrfx_pwm_t const * const p_instance);
+bool nrfx_pwm_is_stopped(nrfx_pwm_t const * p_instance);
 
 /**
  * @brief Function for updating the sequence data during playback.
@@ -339,10 +341,9 @@ bool nrfx_pwm_is_stopped(nrfx_pwm_t const * const p_instance);
  * @param[in] seq_id     Identifier of the sequence (0 or 1).
  * @param[in] p_sequence Pointer to the new sequence definition.
  */
-__STATIC_INLINE void nrfx_pwm_sequence_update(
-                                        nrfx_pwm_t const * const   p_instance,
-                                        uint8_t                    seq_id,
-                                        nrf_pwm_sequence_t const * p_sequence);
+NRFX_STATIC_INLINE void nrfx_pwm_sequence_update(nrfx_pwm_t const *         p_instance,
+                                                 uint8_t                    seq_id,
+                                                 nrf_pwm_sequence_t const * p_sequence);
 
 /**
  * @brief Function for updating the pointer to the duty cycle values
@@ -352,9 +353,9 @@ __STATIC_INLINE void nrfx_pwm_sequence_update(
  * @param[in] seq_id     Identifier of the sequence (0 or 1).
  * @param[in] values     New pointer to the duty cycle values.
  */
-__STATIC_INLINE void nrfx_pwm_sequence_values_update(nrfx_pwm_t const * const p_instance,
-                                                     uint8_t                  seq_id,
-                                                     nrf_pwm_values_t         values);
+NRFX_STATIC_INLINE void nrfx_pwm_sequence_values_update(nrfx_pwm_t const * p_instance,
+                                                        uint8_t            seq_id,
+                                                        nrf_pwm_values_t   values);
 
 /**
  * @brief Function for updating the number of duty cycle values
@@ -364,21 +365,21 @@ __STATIC_INLINE void nrfx_pwm_sequence_values_update(nrfx_pwm_t const * const p_
  * @param[in] seq_id     Identifier of the sequence (0 or 1).
  * @param[in] length     New number of the duty cycle values.
  */
-__STATIC_INLINE void nrfx_pwm_sequence_length_update(nrfx_pwm_t const * const p_instance,
-                                                     uint8_t                  seq_id,
-                                                     uint16_t                 length);
+NRFX_STATIC_INLINE void nrfx_pwm_sequence_length_update(nrfx_pwm_t const * p_instance,
+                                                        uint8_t            seq_id,
+                                                        uint16_t           length);
 
 /**
  * @brief Function for updating the number of repeats for duty cycle values
- *        in specified sequence during playback.
+ *        in the specified sequence during playback.
  *
  * @param[in] p_instance Pointer to the driver instance structure.
  * @param[in] seq_id     Identifier of the sequence (0 or 1).
  * @param[in] repeats    New number of repeats.
  */
-__STATIC_INLINE void nrfx_pwm_sequence_repeats_update(nrfx_pwm_t const * const p_instance,
-                                                      uint8_t                  seq_id,
-                                                      uint32_t                 repeats);
+NRFX_STATIC_INLINE void nrfx_pwm_sequence_repeats_update(nrfx_pwm_t const * p_instance,
+                                                         uint8_t            seq_id,
+                                                         uint32_t           repeats);
 
 /**
  * @brief Function for updating the additional delay after the specified
@@ -388,9 +389,9 @@ __STATIC_INLINE void nrfx_pwm_sequence_repeats_update(nrfx_pwm_t const * const p
  * @param[in] seq_id     Identifier of the sequence (0 or 1).
  * @param[in] end_delay  New end delay value (in PWM periods).
  */
-__STATIC_INLINE void nrfx_pwm_sequence_end_delay_update(nrfx_pwm_t const * const p_instance,
-                                                        uint8_t                  seq_id,
-                                                        uint32_t                 end_delay);
+NRFX_STATIC_INLINE void nrfx_pwm_sequence_end_delay_update(nrfx_pwm_t const * p_instance,
+                                                           uint8_t            seq_id,
+                                                           uint32_t           end_delay);
 
 /**
  * @brief Function for returning the address of a specified PWM task that can
@@ -401,76 +402,76 @@ __STATIC_INLINE void nrfx_pwm_sequence_end_delay_update(nrfx_pwm_t const * const
  *
  * @return Task address.
  */
-__STATIC_INLINE uint32_t nrfx_pwm_task_address_get(nrfx_pwm_t const * const p_instance,
-                                                   nrf_pwm_task_t           task);
+NRFX_STATIC_INLINE uint32_t nrfx_pwm_task_address_get(nrfx_pwm_t const * p_instance,
+                                                      nrf_pwm_task_t     task);
 
-/**@brief Function for returning the address of a specified PWM event that can
+/**
+ * @brief Function for returning the address of a specified PWM event that can
  *        be used in PPI module.
  *
- * @param[in] p_instance Pointer to the driver instance structure.
- * @param[in] event      Requested event.
+ * @param[in] p_instance  Pointer to the driver instance structure.
+ * @param[in] event       Requested event.
  *
  * @return Event address.
  */
-__STATIC_INLINE uint32_t nrfx_pwm_event_address_get(nrfx_pwm_t const * const p_instance,
-                                                    nrf_pwm_event_t          event);
+NRFX_STATIC_INLINE uint32_t nrfx_pwm_event_address_get(nrfx_pwm_t const * p_instance,
+                                                       nrf_pwm_event_t    event);
 
-
-#ifndef SUPPRESS_INLINE_IMPLEMENTATION
-
-__STATIC_INLINE void nrfx_pwm_step(nrfx_pwm_t const * const p_instance)
+#ifndef NRFX_DECLARE_ONLY
+NRFX_STATIC_INLINE void nrfx_pwm_step(nrfx_pwm_t const * p_instance)
 {
     nrf_pwm_task_trigger(p_instance->p_registers, NRF_PWM_TASK_NEXTSTEP);
 }
 
-__STATIC_INLINE void nrfx_pwm_sequence_update(nrfx_pwm_t const * const   p_instance,
-                                              uint8_t                    seq_id,
-                                              nrf_pwm_sequence_t const * p_sequence)
+NRFX_STATIC_INLINE void nrfx_pwm_sequence_update(nrfx_pwm_t const *         p_instance,
+                                                 uint8_t                    seq_id,
+                                                 nrf_pwm_sequence_t const * p_sequence)
 {
     nrf_pwm_sequence_set(p_instance->p_registers, seq_id, p_sequence);
 }
 
-__STATIC_INLINE void nrfx_pwm_sequence_values_update(nrfx_pwm_t const * const p_instance,
-                                                     uint8_t                  seq_id,
-                                                     nrf_pwm_values_t         values)
+NRFX_STATIC_INLINE void nrfx_pwm_sequence_values_update(nrfx_pwm_t const * p_instance,
+                                                        uint8_t            seq_id,
+                                                        nrf_pwm_values_t   values)
 {
     nrf_pwm_seq_ptr_set(p_instance->p_registers, seq_id, values.p_raw);
 }
 
-__STATIC_INLINE void nrfx_pwm_sequence_length_update(nrfx_pwm_t const * const p_instance,
-                                                     uint8_t                  seq_id,
-                                                     uint16_t                 length)
+NRFX_STATIC_INLINE void nrfx_pwm_sequence_length_update(nrfx_pwm_t const * p_instance,
+                                                        uint8_t            seq_id,
+                                                        uint16_t           length)
 {
     nrf_pwm_seq_cnt_set(p_instance->p_registers, seq_id, length);
 }
 
-__STATIC_INLINE void nrfx_pwm_sequence_repeats_update(nrfx_pwm_t const * const p_instance,
-                                                      uint8_t                  seq_id,
-                                                      uint32_t                 repeats)
+NRFX_STATIC_INLINE void nrfx_pwm_sequence_repeats_update(nrfx_pwm_t const * p_instance,
+                                                         uint8_t            seq_id,
+                                                         uint32_t           repeats)
 {
     nrf_pwm_seq_refresh_set(p_instance->p_registers, seq_id, repeats);
 }
 
-__STATIC_INLINE void nrfx_pwm_sequence_end_delay_update(nrfx_pwm_t const * const p_instance,
-                                                        uint8_t                  seq_id,
-                                                        uint32_t                 end_delay)
+NRFX_STATIC_INLINE void nrfx_pwm_sequence_end_delay_update(nrfx_pwm_t const * p_instance,
+                                                           uint8_t            seq_id,
+                                                           uint32_t           end_delay)
 {
     nrf_pwm_seq_end_delay_set(p_instance->p_registers, seq_id, end_delay);
 }
 
-__STATIC_INLINE uint32_t nrfx_pwm_task_address_get(nrfx_pwm_t const * const p_instance,
-                                                   nrf_pwm_task_t           task)
+NRFX_STATIC_INLINE uint32_t nrfx_pwm_task_address_get(nrfx_pwm_t const * p_instance,
+                                                      nrf_pwm_task_t     task)
 {
     return nrf_pwm_task_address_get(p_instance->p_registers, task);
 }
 
-__STATIC_INLINE uint32_t nrfx_pwm_event_address_get(nrfx_pwm_t const * const p_instance,
-                                                    nrf_pwm_event_t          event)
+NRFX_STATIC_INLINE uint32_t nrfx_pwm_event_address_get(nrfx_pwm_t const * p_instance,
+                                                       nrf_pwm_event_t    event)
 {
     return nrf_pwm_event_address_get(p_instance->p_registers, event);
 }
+#endif // NRFX_DECLARE_ONLY
 
-#endif // SUPPRESS_INLINE_IMPLEMENTATION
+/** @} */
 
 
 void nrfx_pwm_0_irq_handler(void);
@@ -479,8 +480,6 @@ void nrfx_pwm_2_irq_handler(void);
 void nrfx_pwm_3_irq_handler(void);
 
 
-/** @} */
-
 #ifdef __cplusplus
 }
 #endif
