@@ -505,8 +505,7 @@ type UART struct {
 }
 
 var (
-	// UART0 is actually a USB CDC interface.
-	UART0 = USBCDC{Buffer: NewRingBuffer()}
+	USB = &USBCDC{Buffer: NewRingBuffer()}
 )
 
 const (
@@ -515,7 +514,7 @@ const (
 )
 
 // Configure the UART.
-func (uart UART) Configure(config UARTConfig) error {
+func (uart *UART) Configure(config UARTConfig) error {
 	// Default baud rate to 115200.
 	if config.BaudRate == 0 {
 		config.BaudRate = 115200
@@ -614,7 +613,7 @@ func (uart UART) Configure(config UARTConfig) error {
 }
 
 // SetBaudRate sets the communication speed for the UART.
-func (uart UART) SetBaudRate(br uint32) {
+func (uart *UART) SetBaudRate(br uint32) {
 	// Asynchronous fractional mode (Table 24-2 in datasheet)
 	//   BAUD = fref / (sampleRateValue * fbaud)
 	// (multiply by 8, to calculate fractional piece)
@@ -628,7 +627,7 @@ func (uart UART) SetBaudRate(br uint32) {
 }
 
 // WriteByte writes a byte of data to the UART.
-func (uart UART) WriteByte(c byte) error {
+func (uart *UART) WriteByte(c byte) error {
 	// wait until ready to receive
 	for !uart.Bus.INTFLAG.HasBits(sam.SERCOM_USART_INTFLAG_DRE) {
 	}
@@ -1788,7 +1787,7 @@ func (usbcdc *USBCDC) Flush() error {
 
 			// send data by setting bank ready
 			setEPSTATUSSET(usb_CDC_ENDPOINT_IN, sam.USB_DEVICE_EPSTATUSSET_BK1RDY)
-			UART0.sent = true
+			usbcdc.sent = true
 		}
 	}
 	return nil
@@ -1802,10 +1801,10 @@ func (usbcdc *USBCDC) WriteByte(c byte) error {
 		for {
 			mask := interrupt.Disable()
 
-			idx := UART0.TxIdx.Get()
+			idx := usbcdc.TxIdx.Get()
 			if (idx & usbcdcTxSizeMask) < usbcdcTxSizeMask {
 				udd_ep_in_cache_buffer[usb_CDC_ENDPOINT_IN][idx] = c
-				UART0.TxIdx.Set(idx + 1)
+				usbcdc.TxIdx.Set(idx + 1)
 				ok = true
 			}
 
@@ -1813,26 +1812,26 @@ func (usbcdc *USBCDC) WriteByte(c byte) error {
 
 			if ok {
 				break
-			} else if usbcdcTxMaxRetriesAllowed < UART0.waitTxcRetryCount {
+			} else if usbcdcTxMaxRetriesAllowed < usbcdc.waitTxcRetryCount {
 				mask := interrupt.Disable()
-				UART0.waitTxc = false
-				UART0.waitTxcRetryCount = 0
-				UART0.TxIdx.Set(0)
+				usbcdc.waitTxc = false
+				usbcdc.waitTxcRetryCount = 0
+				usbcdc.TxIdx.Set(0)
 				usbLineInfo.lineState = 0
 				interrupt.Restore(mask)
 				break
 			} else {
 				mask := interrupt.Disable()
-				if UART0.sent {
-					if UART0.waitTxc {
+				if usbcdc.sent {
+					if usbcdc.waitTxc {
 						if (getEPINTFLAG(usb_CDC_ENDPOINT_IN) & sam.USB_DEVICE_EPINTFLAG_TRCPT1) != 0 {
 							setEPSTATUSCLR(usb_CDC_ENDPOINT_IN, sam.USB_DEVICE_EPSTATUSCLR_BK1RDY)
 							setEPINTFLAG(usb_CDC_ENDPOINT_IN, sam.USB_DEVICE_EPINTFLAG_TRCPT1)
-							UART0.waitTxc = false
-							UART0.Flush()
+							usbcdc.waitTxc = false
+							usbcdc.Flush()
 						}
 					} else {
-						UART0.Flush()
+						usbcdc.Flush()
 					}
 				}
 				interrupt.Restore(mask)
@@ -1843,11 +1842,11 @@ func (usbcdc *USBCDC) WriteByte(c byte) error {
 	return nil
 }
 
-func (usbcdc USBCDC) DTR() bool {
+func (usbcdc *USBCDC) DTR() bool {
 	return (usbLineInfo.lineState & usb_CDC_LINESTATE_DTR) > 0
 }
 
-func (usbcdc USBCDC) RTS() bool {
+func (usbcdc *USBCDC) RTS() bool {
 	return (usbLineInfo.lineState & usb_CDC_LINESTATE_RTS) > 0
 }
 
@@ -1882,7 +1881,7 @@ var (
 )
 
 // Configure the USB CDC interface. The config is here for compatibility with the UART interface.
-func (usbcdc USBCDC) Configure(config UARTConfig) {
+func (usbcdc *USBCDC) Configure(config UARTConfig) {
 	// reset USB interface
 	sam.USB_DEVICE.CTRLA.SetBits(sam.USB_DEVICE_CTRLA_SWRST)
 	for sam.USB_DEVICE.SYNCBUSY.HasBits(sam.USB_DEVICE_SYNCBUSY_SWRST) ||
@@ -1959,7 +1958,7 @@ func handlePadCalibration() {
 	sam.USB_DEVICE.PADCAL.SetBits(calibTransP << sam.USB_DEVICE_PADCAL_TRANSP_Pos)
 
 	if calibTrim == 0x7 {
-		calibTransN = 3
+		calibTrim = 3
 	}
 	sam.USB_DEVICE.PADCAL.SetBits(calibTrim << sam.USB_DEVICE_PADCAL_TRIM_Pos)
 }
@@ -1985,7 +1984,7 @@ func handleUSB(intr interrupt.Interrupt) {
 
 	// Start of frame
 	if (flags & sam.USB_DEVICE_INTFLAG_SOF) > 0 {
-		UART0.Flush()
+		USB.Flush()
 		// if you want to blink LED showing traffic, this would be the place...
 	}
 
@@ -2045,7 +2044,7 @@ func handleUSB(intr interrupt.Interrupt) {
 				setEPINTFLAG(i, sam.USB_DEVICE_EPINTFLAG_TRCPT1)
 
 				if i == usb_CDC_ENDPOINT_IN {
-					UART0.waitTxc = false
+					USB.waitTxc = false
 				}
 			}
 		}
@@ -2359,7 +2358,7 @@ func handleEndpoint(ep uint32) {
 
 	// move to ring buffer
 	for i := 0; i < count; i++ {
-		UART0.Receive(byte((udd_ep_out_cache_buffer[ep][i] & 0xFF)))
+		USB.Receive(byte((udd_ep_out_cache_buffer[ep][i] & 0xFF)))
 	}
 
 	// set byte count to zero
