@@ -8,8 +8,6 @@ import (
 	"unsafe"
 )
 
-type PinMode uint8
-
 const (
 	PinInput PinMode = iota
 	PinInputPullup
@@ -141,16 +139,3 @@ func (a ADC) Get() uint16 {
 
 	return uint16(avr.ADCL.Get()) | uint16(avr.ADCH.Get())<<8
 }
-
-// I2C on AVR.
-type I2C struct {
-}
-
-// I2C0 is the only I2C interface on most AVRs.
-var I2C0 = I2C{}
-
-// UART
-var (
-	// UART0 is the hardware serial port on the AVR.
-	UART0 = UART{Buffer: NewRingBuffer()}
-)
