@@ -31,6 +31,13 @@ const (
 // Also, the stm32f1xx series handles things differently from the stm32f0/2/3/4
 
 // ---------- General pin operations ----------
+type PinChange uint8
+
+const (
+	PinRising PinChange = 1 << iota
+	PinFalling
+	PinToggle = PinRising | PinFalling
+)
 
 // Set the pin to high or low.
 // Warning: only use this on an output pin!
@@ -51,3 +58,19 @@ func (p Pin) Get() bool {
 	val := port.IDR.Get() & (1 << pin)
 	return (val > 0)
 }
+
+// PortMaskSet returns the register and mask to enable a given GPIO pin. This
+// can be used to implement bit-banged drivers.
+func (p Pin) PortMaskSet() (*uint32, uint32) {
+	port := p.getPort()
+	pin := uint8(p) % 16
+	return &port.BSRR.Reg, 1 << pin
+}
+
+// PortMaskClear returns the register and mask to disable a given port. This can
+// be used to implement bit-banged drivers.
+func (p Pin) PortMaskClear() (*uint32, uint32) {
+	port := p.getPort()
+	pin := uint8(p) % 16
+	return &port.BSRR.Reg, 1 << (pin + 16)
+}
